==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/machinelearningservices/kotlin/inputs/ProbeSettingsArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.machinelearningservices.kotlin.inputs

import com.pulumi.azurenative.machinelearningservices.inputs.ProbeSettingsArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.Int
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * Deployment container liveness/readiness probe configuration.
 * @property failureThreshold The number of failures to allow before returning an unhealthy status.
 * @property initialDelay The delay before the first probe in ISO 8601 format.
 * @property period The length of time between probes in ISO 8601 format.
 * @property successThreshold The number of successful probes before returning a healthy status.
 * @property timeout The probe timeout in ISO 8601 format.
 */
public data class ProbeSettingsArgs(
    public val failureThreshold: Output<Int>? = null,
    public val initialDelay: Output<String>? = null,
    public val period: Output<String>? = null,
    public val successThreshold: Output<Int>? = null,
    public val timeout: Output<String>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.machinelearningservices.inputs.ProbeSettingsArgs> {
    override fun toJava(): com.pulumi.azurenative.machinelearningservices.inputs.ProbeSettingsArgs =
        com.pulumi.azurenative.machinelearningservices.inputs.ProbeSettingsArgs.builder()
            .failureThreshold(failureThreshold?.applyValue({ args0 -> args0 }))
            .initialDelay(initialDelay?.applyValue({ args0 -> args0 }))
            .period(period?.applyValue({ args0 -> args0 }))
            .successThreshold(successThreshold?.applyValue({ args0 -> args0 }))
            .timeout(timeout?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [ProbeSettingsArgs].
 */
@PulumiTagMarker
public class ProbeSettingsArgsBuilder internal constructor() {
    private var failureThreshold: Output<Int>? = null

    private var initialDelay: Output<String>? = null

    private var period: Output<String>? = null

    private var successThreshold: Output<Int>? = null

    private var timeout: Output<String>? = null

    /**
     * @param value The number of failures to allow before returning an unhealthy status.
     */
    @JvmName("dhhurkoskytaqhjf")
    public suspend fun failureThreshold(`value`: Output<Int>) {
        this.failureThreshold = value
    }

    /**
     * @param value The delay before the first probe in ISO 8601 format.
     */
    @JvmName("jvnpwaddvasjndmg")
    public suspend fun initialDelay(`value`: Output<String>) {
        this.initialDelay = value
    }

    /**
     * @param value The length of time between probes in ISO 8601 format.
     */
    @JvmName("itwdpllcruxnjvoo")
    public suspend fun period(`value`: Output<String>) {
        this.period = value
    }

    /**
     * @param value The number of successful probes before returning a healthy status.
     */
    @JvmName("ujhxofiowvqqylnv")
    public suspend fun successThreshold(`value`: Output<Int>) {
        this.successThreshold = value
    }

    /**
     * @param value The probe timeout in ISO 8601 format.
     */
    @JvmName("sdfsdnyqpexgvvgq")
    public suspend fun timeout(`value`: Output<String>) {
        this.timeout = value
    }

    /**
     * @param value The number of failures to allow before returning an unhealthy status.
     */
    @JvmName("tbdtwnnndxcuvnfx")
    public suspend fun failureThreshold(`value`: Int?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.failureThreshold = mapped
    }

    /**
     * @param value The delay before the first probe in ISO 8601 format.
     */
    @JvmName("cmnggewpwdkylfkx")
    public suspend fun initialDelay(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.initialDelay = mapped
    }

    /**
     * @param value The length of time between probes in ISO 8601 format.
     */
    @JvmName("brrrasdndmdvyatx")
    public suspend fun period(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.period = mapped
    }

    /**
     * @param value The number of successful probes before returning a healthy status.
     */
    @JvmName("dusffaigcawvpcwt")
    public suspend fun successThreshold(`value`: Int?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.successThreshold = mapped
    }

    /**
     * @param value The probe timeout in ISO 8601 format.
     */
    @JvmName("ikgxpnvusjpnlahk")
    public suspend fun timeout(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.timeout = mapped
    }

    internal fun build(): ProbeSettingsArgs = ProbeSettingsArgs(
        failureThreshold = failureThreshold,
        initialDelay = initialDelay,
        period = period,
        successThreshold = successThreshold,
        timeout = timeout,
    )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/machinelearningservices/kotlin/inputs/ProbeSettingsArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.machinelearningservices.kotlin.inputs

import com.pulumi.azurenative.machinelearningservices.inputs.ProbeSettingsArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.Int
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * Deployment container liveness/readiness probe configuration.
 * @property failureThreshold The number of failures to allow before returning an unhealthy status.
 * @property initialDelay The delay before the first probe in ISO 8601 format.
 * @property period The length of time between probes in ISO 8601 format.
 * @property successThreshold The number of successful probes before returning a healthy status.
 * @property timeout The probe timeout in ISO 8601 format.
 */
public data class ProbeSettingsArgs(
    public val failureThreshold: Output<Int>? = null,
    public val initialDelay: Output<String>? = null,
    public val period: Output<String>? = null,
    public val successThreshold: Output<Int>? = null,
    public val timeout: Output<String>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.machinelearningservices.inputs.ProbeSettingsArgs> {
    override fun toJava(): com.pulumi.azurenative.machinelearningservices.inputs.ProbeSettingsArgs =
        com.pulumi.azurenative.machinelearningservices.inputs.ProbeSettingsArgs.builder()
            .failureThreshold(failureThreshold?.applyValue({ args0 -> args0 }))
            .initialDelay(initialDelay?.applyValue({ args0 -> args0 }))
            .period(period?.applyValue({ args0 -> args0 }))
            .successThreshold(successThreshold?.applyValue({ args0 -> args0 }))
            .timeout(timeout?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [ProbeSettingsArgs].
 */
@PulumiTagMarker
public class ProbeSettingsArgsBuilder internal constructor() {
    private var failureThreshold: Output<Int>? = null

    private var initialDelay: Output<String>? = null

    private var period: Output<String>? = null

    private var successThreshold: Output<Int>? = null

    private var timeout: Output<String>? = null

    /**
     * @param value The number of failures to allow before returning an unhealthy status.
     */
    @JvmName("vkefnbifbaapyeyb")
    public suspend fun failureThreshold(`value`: Output<Int>) {
        this.failureThreshold = value
    }

    /**
     * @param value The delay before the first probe in ISO 8601 format.
     */
    @JvmName("xrkngawjmbhhrjsf")
    public suspend fun initialDelay(`value`: Output<String>) {
        this.initialDelay = value
    }

    /**
     * @param value The length of time between probes in ISO 8601 format.
     */
    @JvmName("bkxfssjngklorjbv")
    public suspend fun period(`value`: Output<String>) {
        this.period = value
    }

    /**
     * @param value The number of successful probes before returning a healthy status.
     */
    @JvmName("awphecyfxrlucmut")
    public suspend fun successThreshold(`value`: Output<Int>) {
        this.successThreshold = value
    }

    /**
     * @param value The probe timeout in ISO 8601 format.
     */
    @JvmName("tkuqgqsyjtntxlay")
    public suspend fun timeout(`value`: Output<String>) {
        this.timeout = value
    }

    /**
     * @param value The number of failures to allow before returning an unhealthy status.
     */
    @JvmName("xopjbybhwdfoxjdb")
    public suspend fun failureThreshold(`value`: Int?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.failureThreshold = mapped
    }

    /**
     * @param value The delay before the first probe in ISO 8601 format.
     */
    @JvmName("rnjfbqobqmuktjym")
    public suspend fun initialDelay(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.initialDelay = mapped
    }

    /**
     * @param value The length of time between probes in ISO 8601 format.
     */
    @JvmName("seskkcbuvbsespdd")
    public suspend fun period(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.period = mapped
    }

    /**
     * @param value The number of successful probes before returning a healthy status.
     */
    @JvmName("wnufjnsjwhfgvjvp")
    public suspend fun successThreshold(`value`: Int?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.successThreshold = mapped
    }

    /**
     * @param value The probe timeout in ISO 8601 format.
     */
    @JvmName("tidiixwwixvdxyai")
    public suspend fun timeout(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.timeout = mapped
    }

    internal fun build(): ProbeSettingsArgs = ProbeSettingsArgs(
        failureThreshold = failureThreshold,
        initialDelay = initialDelay,
        period = period,
        successThreshold = successThreshold,
        timeout = timeout,
    )
}
